@@ -15,6 +15,18 @@ class Singleton:
         return cls._instance
 
 
+class Borg:
+    _dict = None
+
+    def __new__(cls, *args, **kwargs):
+        obj = super().__new__(cls, *args, **kwargs)
+        if cls._dict is None:
+            cls._dict = obj.__dict__
+        else:
+            obj.__dict__ = cls._dict
+        return obj
+
+
 class CreditType(Enum):
     REFERENCE = auto()
     ACKNOWLEDGEMENT = auto()
@@ -162,10 +174,21 @@ class DictChoiceFactory:
             raise ValueError(f"{call_name} is not recognized.")
 
     @classmethod
-    def view_accreditations(
+    def get_accreditations(
         cls,
     ) -> Dict[
         str,
         Tuple[Tuple[Optional[str], Optional[str], Optional[str]], CreditType],
     ]:
         return cls.accreditation.return_accreditations()
+
+    @classmethod
+    def view_accreditations(
+        cls,
+    ) -> None:
+        creditations = cls.accreditation.return_accreditations()
+        for key, value in creditations.items():
+            print(
+                f"Object {key}: Author - {value[0][0]}, Github - {value[0][1]}"
+                + f", Info - {value[0][2]}\n\t Credit Type {value[1]}"
+            )
